Report Module
=============

.. contents::
    :local:

This module can be used to generate a test results report (in pdf format)
using LaTeX.

:mod:`~emva1288.report.report`
------------------------------

.. automodule:: emva1288.report.report
    :members:
    :undoc-members:
    :show-inheritance:
    :special-members: __init__
